summaryrefslogtreecommitdiffstats
path: root/akregator/src/folder.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:50:21 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:50:21 -0600
commit3ca10fd9a2dc631429d3b5d5c5e42a7d211d5a12 (patch)
tree89de88213bd261e4ccaade899ab2d6ec34b3a5a7 /akregator/src/folder.h
parent1dad5f662a09dfc5cc041caffe0f674044a4dcec (diff)
downloadtdepim-3ca10fd9a2dc631429d3b5d5c5e42a7d211d5a12.tar.gz
tdepim-3ca10fd9a2dc631429d3b5d5c5e42a7d211d5a12.zip
Rename a number of old tq methods that are no longer tq specific
Diffstat (limited to 'akregator/src/folder.h')
-rw-r--r--akregator/src/folder.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/akregator/src/folder.h b/akregator/src/folder.h
index 6743dd57..f2a024dd 100644
--- a/akregator/src/folder.h
+++ b/akregator/src/folder.h
@@ -61,18 +61,18 @@ namespace Akregator
virtual bool accept(TreeNodeVisitor* visitor);
- /** returns recursively concatenated articles of tqchildren
- @return an article sequence containing articles of tqchildren */
+ /** returns recursively concatenated articles of children
+ @return an article sequence containing articles of children */
virtual TQValueList<Article> articles(const TQString& tag=TQString());
/** returns a list of all tags occurring in the subtree of this folder */
virtual TQStringList tags() const;
/** returns the number of unread articles in all tqchildren
@return number of unread articles */
virtual int unread() const;
/** returns the number of articles in all tqchildren
@return number of articles */
virtual int totalCount() const;
@@ -86,10 +86,10 @@ namespace Akregator
@return The newly created element representing this feed group */
virtual TQDomElement toOPML( TQDomElement parent, TQDomDocument document ) const;
/** returns the (direct) tqchildren of this node.
@return a list of pointers to the child nodes
*/
- virtual TQValueList<TreeNode*> tqchildren() const;
+ virtual TQValueList<TreeNode*> children() const;
/** inserts @c node as child after child node @c after.
if @c after is not a child of this group, @c node will be inserted as first child
@@ -105,7 +105,7 @@ namespace Akregator
@param node the tree node to insert */
virtual void appendChild(TreeNode* node);
/** remove @c node from tqchildren. Note that @c node will not be deleted
@param node the child node to remove */
virtual void removeChild(TreeNode* node);
@@ -134,7 +134,7 @@ namespace Akregator
/** Delete expired articles recursively. */
virtual void slotDeleteExpiredArticles();
/** Mark articles of tqchildren recursively as read. */
virtual void slotMarkAllArticlesAsRead();
/** Called when a child was modified.
@@ -147,7 +147,7 @@ namespace Akregator
*/
virtual void slotChildDestroyed(TreeNode* node);
/** enqueues tqchildren recursively for fetching
@param queue a fetch queue
@param internvalFetchesOnly */
virtual void slotAddToFetchQueue(FetchQueue* queue, bool intervalFetchesOnly=false);
@@ -61,18 +61,18 @@ namespace Akregator
/** returns a list of all tags occurring in the subtree of this folder */
virtual TQStringList tags() const;
- /** returns the number of unread articles in all tqchildren
+ /** returns the number of unread articles in all children
virtual int unread() const;
@@ -61,18 +61,18 @@ namespace Akregator
virtual int unread() const;
- /** returns the number of articles in all tqchildren
+ /** returns the number of articles in all children
virtual int totalCount() const;
@@ -86,10 +86,10 @@ namespace Akregator
virtual TQDomElement toOPML( TQDomElement parent, TQDomDocument document ) const;
- /** returns the (direct) tqchildren of this node.
+ /** returns the (direct) children of this node.
*/
@@ -105,7 +105,7 @@ namespace Akregator
virtual void appendChild(TreeNode* node);
- /** remove @c node from tqchildren. Note that @c node will not be deleted
+ /** remove @c node from children. Note that @c node will not be deleted
virtual void removeChild(TreeNode* node);
@@ -134,7 +134,7 @@ namespace Akregator
/** Delete expired articles recursively. */
virtual void slotDeleteExpiredArticles();
- /** Mark articles of tqchildren recursively as read. */
+ /** Mark articles of children recursively as read. */
virtual void slotMarkAllArticlesAsRead();
/** Called when a child was modified.
@@ -147,7 +147,7 @@ namespace Akregator
*/
virtual void slotChildDestroyed(TreeNode* node);
- /** enqueues tqchildren recursively for fetching
+ /** enqueues children recursively for fetching